@@ -542,21 +542,21 @@ int set_defaults_interactive(char *fn) {
 
   if (!getval("connection")) {
     if (!info.daemon) {
-      wp(NULL, "
-          Connection | Number
-          -------------------
-          Unknown    |  0
-          14.4       |  1
-          28.8       |  2
-          33.6       |  3
-          56.7       |  4
-          64K ISDN   |  5
-          128K ISDN  |  6
-          Cable      |  7
-          DSL        |  8
-          T1         |  9
-          T3 or >    | 10
-\n");
+      wp(NULL, 
+	 "          Connection | Number\n"
+	 "          -------------------\n"
+	 "          Unknown    |  0\n"
+	 "          14.4       |  1\n"
+	 "          28.8       |  2\n"
+	 "          33.6       |  3\n"
+	 "          56.7       |  4\n"
+	 "          64K ISDN   |  5\n"
+	 "          128K ISDN  |  6\n"
+	 "          Cable      |  7\n"
+	 "          DSL        |  8\n"
+	 "          T1         |  9\n"
+	 "          T3 or >    | 10\n"
+	 );
       wp(NULL, "How fast is your internet connection?\n");
       wp(NULL, "Please choose 0--10 from the chart: [4] ");
       ans = nap_getline(stdin);
@@ -1317,7 +1317,7 @@ int main(int argc, char *argv[])
     if (info.create)
     {
       wp(NULL, "Creating account...\n");
-      n = makeact(s, info.user, info.pass, info.port, CLIENT, c, info.email);
+      n = makeact(s, info.user, info.pass, info.port, c, info.email);
       if (n == -1)
       {
         close(s);
@@ -1333,7 +1333,7 @@ int main(int argc, char *argv[])
     else
     {
       wp(NULL, "Logging in...\n");
-      n = login(s, info.user, info.pass, info.port, CLIENT, c, info.email);
+      n = login(s, info.user, info.pass, info.port, c, info.email);
       if (n == -1)
       {
         close(s);
@@ -1585,12 +1585,13 @@ int conn(char *host)
   return(s);
 }
 
-int login(int s, char *user, char *pass, int data, char *client, int conn, char *email)
+int login(int s, char *user, char *pass, int data, int conn, char *email)
 {
-  char *t1=NULL;
+  char *t1;
   phead_t *rcv;
   int r;
   int timeout;
+  char *identity = getval("identity");
 
   timeout = nvar_default("connecttimeout", CONNECTTIMEOUT);
 
@@ -1598,17 +1599,13 @@ int login(int s, char *user, char *pass, int data, char *client, int conn, char
     timeout=-1;
   }
 
-  msprintf(&t1, "nap v%s", client);
-  r = sendpack(s, F_LOGIN, "%s %s %i \"%s\" %i", user, pass, data, t1, conn);
+  r = sendpack(s, NAP_LOGIN, "%s %s %i \"%s\" %i", user, pass, data, identity ? identity : IDENTITY, conn);
   if (r<0) {
     wp(wchan, "Error: %s\n", strerror(errno));
     drw(wchan);
-    free(t1);
     return(-1);
   }
 
-  free(t1);
-  t1 = NULL;
   r = recvpack_t(s, &t1, &rcv, timeout);
   while (r == -2) {
     r = recvpack_t(s, &t1, &rcv, timeout);
@@ -1628,7 +1625,7 @@ int login(int s, char *user, char *pass, int data, char *client, int conn, char
     return(-1);
   }
 
-  if (rcv->op == F_LOGERROR)
+  if (rcv->op == NAP_LOGERROR)
   {
     wp(wchan, "Error: %s\n", t1);
     drw(wchan);
@@ -1655,28 +1652,47 @@ int login(int s, char *user, char *pass, int data, char *client, int conn, char
   return r;
 }
 
-int makeact(int s, char *user, char *pass, int data, char *client, int conn, char *email)
+int makeact(int s, char *user, char *pass, int data, int conn, char *email)
 {
   char *t1=NULL;
   phead_t *rcv;
   int r;
+  int timeout;
+  char *identity = getval("identity");
 
-  sendpack(s, F_MKUSER, user);
-  r = recvpack(s, &t1, &rcv);
-  while (r == -2)
-    r = recvpack(s, &t1, &rcv);
+  timeout = nvar_default("connecttimeout", CONNECTTIMEOUT);
+
+  if (timeout==0) {
+    timeout=-1;
+  }
+
+  r = sendpack(s, NAP_MKUSER, user);
+  if (r<0) {
+    wp(wchan, "Error: %s\n", strerror(errno));
+    drw(wchan);
+    return(-1);
+  }
+  
+  r = recvpack_t(s, &t1, &rcv, timeout);
+  while (r == -2) {
+    r = recvpack_t(s, &t1, &rcv, timeout);
+  }
 
   if (r == -1) {
-    wp(wchan, "Error: %s\n", strerror(errno));
+    wp(wchan, "Error while receiving data: %s\n", strerror(errno));
     drw(wchan);
     return(-1);
   } else if (r == -3) {
     wp(wchan, "Error: unexpected end of file from server\n");
     drw(wchan);
     return(-1);
+  } else if (r == -4) {
+    wp(wchan, "Error: Connection timed out\n");
+    drw(wchan);
+    return(-1);
   }
   
-  if (rcv->op == F_UNTK)
+  if (rcv->op == NAP_UNTK)
   {
     wp(wchan, "Error: Username taken\n");
     drw(wchan);
@@ -1684,7 +1700,7 @@ int makeact(int s, char *user, char *pass, int data, char *client, int conn, cha
     free(rcv);
     return(-1);
   }
-  else if (rcv->op == F_UNBAD)
+  else if (rcv->op == NAP_UNBAD)
   {
     wp(wchan, "Error: Invalid username\n");
     drw(wchan);
@@ -1692,7 +1708,7 @@ int makeact(int s, char *user, char *pass, int data, char *client, int conn, cha
     free(rcv);
     return(-1);
   }
-  else if (rcv->op == F_UNOK) {
+  else if (rcv->op == NAP_UNOK) {
     wp(wchan, "Registered username\n");
     drw(wchan);
   }
@@ -1709,25 +1725,33 @@ int makeact(int s, char *user, char *pass, int data, char *client, int conn, cha
   free(rcv);
   t1 = NULL;
   
-  msprintf(&t1, "nap v%s", client);
-  sendpack(s, F_REG, "%s %s %i \"%s\" %i %s", user, pass, data, t1, conn, email);
-  free(t1);
-  t1 = NULL;
-  r = recvpack(s, &t1, &rcv);
-  while (r == -2)
-    r = recvpack(s, &t1, &rcv);
+  r = sendpack(s, NAP_REG, "%s %s %i \"%s\" %i %s", user, pass, data, identity ? identity : IDENTITY, conn, email);
+  if (r<0) {
+    wp(wchan, "Error: %s\n", strerror(errno));
+    drw(wchan);
+    return(-1);
+  }
+
+  r = recvpack_t(s, &t1, &rcv, timeout);
+  while (r == -2) {
+    r = recvpack_t(s, &t1, &rcv, timeout);
+  }
 
   if (r == -1) {
-    wp(wchan, "Error: %s\n", strerror(errno));
+    wp(wchan, "Error while receiving data: %s\n", strerror(errno));
     drw(wchan);
     return(-1);
   } else if (r == -3) {
     wp(wchan, "Error: unexpected end of file from server\n");
     drw(wchan);
     return(-1);
+  } else if (r == -4) {
+    wp(wchan, "Error: Connection timed out\n");
+    drw(wchan);
+    return(-1);
   }
   
-  if (rcv->op == F_LOGERROR)
+  if (rcv->op == NAP_LOGERROR)
   {
     wp(wchan, "Error: %s\n", t1);
     drw(wchan);
@@ -1736,6 +1760,18 @@ int makeact(int s, char *user, char *pass, int data, char *client, int conn, cha
     return(-1);
   }
   
+  /* the following works for opennap and slavanap. The "email address"
+     they send is of the form anon@servername. Slavanap also sends an
+     additional integer. */
+  if (strncmp(t1, "anon@", 5)==0) {
+    char *p = strchr(t1, ' ');
+    if (p) {
+      *p = 0;
+    }
+    wp(wchan, "Server's name appears to be %s\n", t1+5);
+    drw(wchan);
+  }
+
   free(t1);
   free(rcv);
   
@@ -1944,7 +1980,7 @@ int loadchans(int s, char *fn)
       break;
     }
     if (*line != 0)
-      sendpack(s, F_JOIN, "%s", line);
+      sendpack(s, NAP_JOIN, "%s", line);
     free(line);
   }
   
