@@ -91,52 +91,52 @@ int tin = 0;
 scount_t scount;           /* libraries / songs / gigs */
 
 in_nap_cmd_t in[] = {
-	 { F_SRET, ssret },
-	 { F_SEND, ssend },
-	 { F_RBROWSE, srbrowse },
-	 { F_DBROWSE, sdbrowse },
-	 { F_SGET, sget },
-	 { F_NGET, snget },
-	 { F_NACC, snacc },
-	 { F_RQLIMIT, sqlimit },
-	 { F_FREQ, sfreq },
-	 { F_SSF, ssf },
-	 { F_COUNT, sscount },
-         { F_BROWSE2ACC, sbrowse2acc },
-         { F_BROWSE2ERR, sbrowse2err },
-         { F_BROWSE2, sbrowse2req },
-	 { F_SWHOIS, swhois },
-	 { F_SOFF, soff },
-	 { F_UON, suon },
-	 { F_UOFF, suoff },
-	 { F_NOTICE, snotice },
-	 { F_RY, sry },
-	 { F_SJOIN, sjoin },
-	 { F_SPART, spart },
-	 { F_PART, smpart },
-	 { F_TOPIC, stopic },
-	 { F_SAID, ssay },
-	 { F_NCHAN, snchan },
-	 { F_JCHAN, sjchan },
-	 { F_MNAME, snend },
-	 { F_MNAME2, snend },
-	 { F_TELL, stell },
-	 { F_USER, suser },
-	 { F_SOP, sop },
-	 { F_PCHANGE, spchange },
-	 { F_BPORT, sbport },
-	 { F_ANNOUNCE, sannounce },
-	 { F_SBANLIST, sbanlist },
-	 { F_SBANLISTU, sbanlist },
+	 { NAP_SRET, ssret },
+	 { NAP_SEND, ssend },
+	 { NAP_RBROWSE, srbrowse },
+	 { NAP_DBROWSE, sdbrowse },
+	 { NAP_SGET, sget },
+	 { NAP_NGET, snget },
+	 { NAP_NACC, snacc },
+	 { NAP_RQLIMIT, sqlimit },
+	 { NAP_FREQ, sfreq },
+	 { NAP_SSF, ssf },
+	 { NAP_COUNT, sscount },
+         { NAP_BROWSE2ACC, sbrowse2acc },
+         { NAP_BROWSE2ERR, sbrowse2err },
+         { NAP_BROWSE2, sbrowse2req },
+	 { NAP_SWHOIS, swhois },
+	 { NAP_SOFF, soff },
+	 { NAP_UON, suon },
+	 { NAP_UOFF, suoff },
+	 { NAP_NOTICE, snotice },
+	 { NAP_RY, sry },
+	 { NAP_SJOIN, sjoin },
+	 { NAP_SPART, spart },
+	 { NAP_PART, smpart },
+	 { NAP_TOPIC, stopic },
+	 { NAP_SAID, ssay },
+	 { NAP_NCHAN, snchan },
+	 { NAP_JCHAN, sjchan },
+	 { NAP_MNAME, snend },
+	 { NAP_MNAME2, snend },
+	 { NAP_TELL, stell },
+	 { NAP_USER, suser },
+	 { NAP_SOP, sop },
+	 { NAP_PCHANGE, spchange },
+	 { NAP_BPORT, sbport },
+	 { NAP_ANNOUNCE, sannounce },
+	 { NAP_SBANLIST, sbanlist },
+	 { NAP_SBANLISTU, sbanlist },
 	 { SERVER_PING, ssping },
 	 { CLIENT_PING, scping },
 	 { CLIENT_PONG, scpong },
 	 { CLIENT_REDIRECT, sredir },
 	 { CLIENT_CYCLE, scycle },
-	 { F_SCLIST, sclist },
+	 { NAP_SCLIST, sclist },
 	 { CHANNEL_ENTRY2, sclist2 },
-	 { F_NAMES, suser },
-	 { F_SBLOCKLIST, sblocklist },
+	 { NAP_NAMES, suser },
+	 { NAP_SBLOCKLIST, sblocklist },
 	 { IGNORE_LIST, signoreend },
 	 { IGNORE_ENTRY, signorelist },
 	 { IGNORE_ADD, signoreadd },
@@ -536,7 +536,7 @@ I_NAP_FUNC(stell)
        infinite chats between two autoreplying clients */
     if (!(lastreply && !strcmp(lastreply, tok[0]))) {
       autoreply = strdup(autoreply);
-      sendpack(s, F_TELL, "%s %s", tok[0], fixquotes(autoreply));
+      sendpack(s, NAP_TELL, "%s %s", tok[0], fixquotes(autoreply));
       wp(win, "%s* --> (%s%s%s)%s %s\n", GREEN, WHITE, tok[0], GREEN, WHITE, autoreply);
       drw(win);
       free(autoreply);
@@ -978,7 +978,7 @@ I_NAP_FUNC(sfreq)
   }
 
   if (!isshared(lfn, libraryfile)) {
-    sendpack(s, F_GFR, "%s", str);  /* see comment below */
+    sendpack(s, NAP_GFR, "%s", str);  /* see comment below */
     wp(win, "%s* File \"%s\" was requested by %s, but is not shared!%s\n", RED, lfn, tok[0], WHITE);
     drw(win);
     free(lfn);
@@ -990,7 +990,7 @@ I_NAP_FUNC(sfreq)
 
   /* if /tquit is in effect, don't accept any new uploads */
   if (quit_after_transfers) {
-    sendpack(s, F_GFR, "%s", str);
+    sendpack(s, NAP_GFR, "%s", str);
     wp(win, ""RED"* Not accepting new upload of \"%s\" to %s because /tquit is in effect"WHITE"\n", fn, tok[0]);
     drw(win);
     free(lfn);
@@ -1002,13 +1002,13 @@ I_NAP_FUNC(sfreq)
   if (task != NULL)
   {
     /* we are already uploading the file to nick */
-    /* send a F_QLIMIT or send nothing ? F_QLIMIT would be
+    /* send a NAP_QLIMIT or send nothing ? NAP_QLIMIT would be
      * inappropriate.  If the download is not yet IN_PROGRESS, there
      * is no harm in sending an accept to the server (but not adding a
      * duplicate to the list) - maybe the remote user already deleted
      * the first download (which we would not know). -PS */
     if (task->state != IN_PROGRESS) {
-      sendpack(s, F_GFR, "%s", str);
+      sendpack(s, NAP_GFR, "%s", str);
     } else {
       wp(win, ""RED"* Already uploading \"%s\" to %s (duplicate request)"WHITE"\n", fn, tok[0]);
       drw(win);
@@ -1020,13 +1020,13 @@ I_NAP_FUNC(sfreq)
   /* see if global or per-user upload limit exceeded */
   r = upload_limit_reached(tok[0]);
   if (r) {
-    /* sendpack(s, F_GFR, "%s", str); */ /* why is this here ? */ 
+    /* sendpack(s, NAP_GFR, "%s", str); */ /* why is this here ? */ 
     /* apparently the official napster server does not forward QLIMIT
        packets to the requestor, thus keeping them waiting
        forever. However, this is too bad, I don't think we should use
-       F_GFR here. Do the opennap servers react differently? ### check
+       NAP_GFR here. Do the opennap servers react differently? ### check
        this another time. */
-    sendpack(s, F_QLIMIT, "%s \"%s\" %li", tok[0], tok[1], r==2 ? nvar("maxuploads") : nvar("maxupuser"));
+    sendpack(s, NAP_QLIMIT, "%s \"%s\" %li", tok[0], tok[1], r==2 ? nvar("maxuploads") : nvar("maxupuser"));
     if (nvar_default("showtoomanyuploads", 0)) {
       wp(win, "%s* Too many uploads %s(can't send \"%s\" to %s)%s\n", RED, r==2 ? "" : "for this user ", tok[1], tok[0], WHITE);
       drw(win);
@@ -1048,9 +1048,9 @@ I_NAP_FUNC(sfreq)
   /* add it to the upload list */
   list_append(upload_t, up, task);
 
-  /* sendpack(s, F_SX, "%s", task->nm); */ /* why send a link speed query? */
+  /* sendpack(s, NAP_SX, "%s", task->nm); */ /* why send a link speed query? */
   /* accept upload request: <nick> "<filename>" */
-  sendpack(s, F_GFR, "%s", str); 
+  sendpack(s, NAP_GFR, "%s", str); 
 
   return(1);
 }
@@ -1169,14 +1169,14 @@ I_NAP_FUNC(sget)
 
   if (!rport)   /* firewalled client, send push request and go WAITING */
   {
-    sendpack(s, F_DSF, "%s \"%s\"", tok[0], tok[3]);
+    sendpack(s, NAP_DSF, "%s \"%s\"", tok[0], tok[3]);
     task->state = WAITING;
     return(1);
   }
 
   /* else connect to the remote client and go CONNECTING */
 
-  /* sendpack(s, F_SX, "%s", tok[0]); */ /* why send a link speed query? */
+  /* sendpack(s, NAP_SX, "%s", tok[0]); */ /* why send a link speed query? */
 
   k = socket(AF_INET, SOCK_STREAM, 0);
     
@@ -1652,7 +1652,7 @@ I_NAP_FUNC(sbrowse2req)
 
   if (num < 3) {
     /* accept the direct browse request: <nick> */
-    sendpack(s, F_BROWSE2ACC, "%s", tok[0]); 
+    sendpack(s, NAP_BROWSE2ACC, "%s", tok[0]); 
     /* remote client will initiate the connection */
     return(1); 
   }
@@ -1800,7 +1800,7 @@ I_NAP_FUNC(sredir)
   wp(win, "Logging in...\n");
   drw(win);
   c = connection();
-  if (login(t, info.user, info.pass, info.port, CLIENT, c, info.email) == -1)
+  if (login(t, info.user, info.pass, info.port, c, info.email) == -1)
   {
     drw(win);
     close(t);
@@ -1830,7 +1830,7 @@ I_NAP_FUNC(sredir)
   {
     for (cur=chanl;;cur=cur->next)
       if (!cur->q)
-        sendpack(sk->fd, F_JOIN, "%s", cur->nm);
+        sendpack(sk->fd, NAP_JOIN, "%s", cur->nm);
     delnapchans();
   }
   
@@ -1861,7 +1861,7 @@ I_NAP_FUNC(scycle)
   wp(win, "Logging in...\n");
   drw(win);
   c = connection();
-  if (login(t, info.user, info.pass, info.port, CLIENT, c, info.email) == -1)
+  if (login(t, info.user, info.pass, info.port, c, info.email) == -1)
   {
     drw(win);
     close(t);
@@ -1891,7 +1891,7 @@ I_NAP_FUNC(scycle)
   {
     for (cur=chanl;;cur=cur->next)
       if (!cur->q)
-        sendpack(sk->fd, F_JOIN, "%s", cur->nm);
+        sendpack(sk->fd, NAP_JOIN, "%s", cur->nm);
     delnapchans();
   }
   
